/// <reference types="node" />
import { CommandClass, type ICommandClassContainer } from "@zwave-js/cc";
import { type FrameType, type MessageOrCCLogEntry, type SinglecastCC } from "@zwave-js/core";
import type { ZWaveHost } from "@zwave-js/host";
import { Message, type MessageBaseOptions, type MessageDeserializationOptions } from "@zwave-js/serial";
export declare enum ApplicationCommandStatusFlags {
    RoutedBusy = 1,// A response route is locked by the application
    LowPower = 2,// Received at low output power level
    TypeSingle = 0,// Received a single cast frame
    TypeBroad = 4,// Received a broad cast frame
    TypeMulti = 8,// Received a multi cast frame
    TypeMask = 12,
    Explore = 16,// Received an explore frame
    ForeignFrame = 64,// Received a foreign frame (only promiscuous mode)
    ForeignHomeId = 128
}
interface ApplicationCommandRequestOptions extends MessageBaseOptions {
    command: CommandClass;
    frameType?: ApplicationCommandRequest["frameType"];
    routedBusy?: boolean;
}
export declare class ApplicationCommandRequest extends Message implements ICommandClassContainer {
    constructor(host: ZWaveHost, options: MessageDeserializationOptions | ApplicationCommandRequestOptions);
    readonly routedBusy: boolean;
    readonly frameType: FrameType;
    readonly isExploreFrame: boolean;
    readonly isForeignFrame: boolean;
    readonly fromForeignHomeId: boolean;
    command: SinglecastCC<CommandClass>;
    getNodeId(): number | undefined;
    serialize(): Buffer;
    toLogEntry(): MessageOrCCLogEntry;
}
export {};
//# sourceMappingURL=ApplicationCommandRequest.d.ts.map